==> flutter_webview_desktop-0.0.19-dev.tar.gz: windows/webview_app.cc <==
#include "webview_app.h"
#include "webview_js_handler.h"
#include <atlstr.h>
#include "include/wrapper/cef_helpers.h"
WebviewApp::WebviewApp() {}

void WebviewApp::OnContextInitialized()
{
   
}
void WebviewApp ::OnWebKitInitialized()
{
    // std::string extensionCode =
    //     "var test;"
    //     "if (!test)"
    //     "  test = {};"
    //     "(function() {"
    //     "  test.myfunc = function() {"
    //     "    native function myfunc();"
    //     "    return myfunc();"
    //     "  };"
    //     "})();";

    // // Create an instance of my CefV8Handler object.
    // CefRefPtr<CefV8Handler> handler = new WebviewJSHandler(fuc_name_, delegate_);

    // // Register the extension.
    // CefRegisterExtension("v8/test", extensionCode, handler);
}
bool WebviewApp::OnProcessMessageReceived(CefRefPtr<CefBrowser> browser,
                                          CefRefPtr<CefFrame> frame,
                                          CefProcessId source_process,
                                          CefRefPtr<CefProcessMessage> message)
{
    CEF_REQUIRE_RENDERER_THREAD();
    CefString name = message->GetName();
    CefRefPtr<CefListValue> args = message->GetArgumentList();
    if (name == "test")
    {
        CefString str = args->GetString(0);
        std::wstring strParams;
        strParams += args->GetString(0).ToWString();
        strParams += args->GetString(1).ToWString();
        strParams += args->GetString(2).ToWString();

        CString strJs;
        strJs.Format(_T("alert('render %s')"), strParams.c_str());
        browser->GetMainFrame()->ExecuteJavaScript(strJs.GetBuffer(0), "", 0);

        //发送一个消息给Browser
        CefRefPtr<CefProcessMessage> browser_message = CefProcessMessage::Create("test");
        CefRefPtr<CefListValue> browser_arg = browser_message->GetArgumentList();
        browser_arg->SetString(0, "hellow0");
        browser_arg->SetString(1, "hellow1");
        browser_arg->SetString(2, "hellow2");
        browser->GetMainFrame()->SendProcessMessage(PID_BROWSER, browser_message);

        return true;
    }

    return false;
}
void WebviewApp::OnContextCreated(CefRefPtr<CefBrowser> browser,
                                  CefRefPtr<CefFrame> frame,
                                  CefRefPtr<CefV8Context> context)
{
    // if (fuc_name_ == "")
    // {
    //     return;
    // }

    CefRefPtr<CefV8Value> object = context->GetGlobal();

    CefRefPtr<CefV8Handler> handler = new WebviewJSHandler( delegate_,"postMessage");

    // Create the "myfunc" function.
    CefRefPtr<CefV8Value> func = CefV8Value::CreateFunction("postMessage", handler);

    // Add the "myfunc" function to the "window" object.
    object->SetValue("postMessage", func, V8_PROPERTY_ATTRIBUTE_NONE);
}
void WebviewApp::OnBeforeCommandLineProcessing(const CefString &process_type,
                                               CefRefPtr<CefCommandLine> command_line)
{
    // disable creation of a GPUCache/ folder on disk
    command_line->AppendSwitch("disable-gpu-shader-disk-cache");

    command_line->AppendArgument("--enable-logging --v=1");
    command_line->AppendSwitch("in-process-gpu");
    // command_line->AppendSwitch("disable-accelerated-video-decode");

    // un-comment to show the built-in Chromium fps meter
    // command_line->AppendSwitch("show-fps-counter");

    // command_line->AppendSwitch("disable-gpu-vsync");

    // Most systems would not need to use this switch - but on older hardware,
    // Chromium may still choose to disable D3D11 for gpu workarounds.
    // Accelerated OSR will not at all with D3D11 disabled, so we force it on.
    //
    // See the discussion on this issue:
    // https://github.com/daktronics/cef-mixer/issues/10
    // //
    // command_line->AppendSwitchWithValue("use-angle", "d3d11");

    // // tell Chromium to autoplay <video> elements without
    // // requiring the muted attribute or user interaction
    // command_line->AppendSwitchWithValue("autoplay-policy", "no-user-gesture-required");

#if !defined(NDEBUG)
    // ~RenderProcessHostImpl() complains about DCHECK(is_self_deleted_)
    // when we run single process mode ... I haven't figured out how to resolve yet
    // command_line->AppendSwitch("single-process");
#endif
}

==> flutter_webview_desktop-0.0.23-dev.tar.gz: windows/webview_app.cc <==
#include "webview_app.h"
#include "webview_js_handler.h"
#include <atlstr.h>
#include "include/wrapper/cef_helpers.h"
WebviewApp::WebviewApp() {}

void WebviewApp::OnContextInitialized()
{
   
}
void WebviewApp ::OnWebKitInitialized()
{
    std::string extensionCode =
        "var windowsBridge;"
        "if (!windowsBridge)"
        "  windowsBridge = {};"
        "(function() {"
        "  windowsBridge.postMessage = function(name,message) {"
        "    native function postMessage(name,message);"
        "    return postMessage(name,message);"
        "  };"
        "})();";

    // std::string extensionCode = "windowsBridge = {\" postMessage \": function(name,message) { native function postMessage(); return postMessage();}}";

    // Create an instance of my CefV8Handler object.
    CefRefPtr<CefV8Handler>
        handler = new WebviewJSHandler("postMessage");

    // Register the extension.
    CefRegisterExtension("v8/windowsBridge", extensionCode, handler);
}
bool WebviewApp::OnProcessMessageReceived(CefRefPtr<CefBrowser> browser,
                                          CefRefPtr<CefFrame> frame,
                                          CefProcessId source_process,
                                          CefRefPtr<CefProcessMessage> message)
{
    CEF_REQUIRE_RENDERER_THREAD();
    CefString name = message->GetName();
    CefRefPtr<CefListValue> args = message->GetArgumentList();
    if (name == "postMessage")
    {
        CefString str = args->GetString(0);
        std::wstring strParams;
        strParams += args->GetString(0).ToWString();
        strParams += args->GetString(1).ToWString();
        strParams += args->GetString(2).ToWString();

        CString strJs;
        strJs.Format(_T("alert('render %s')"), strParams.c_str());
        browser->GetMainFrame()->ExecuteJavaScript(strJs.GetBuffer(0), "", 0);

        //发送一个消息给Browser
        CefRefPtr<CefProcessMessage> browser_message = CefProcessMessage::Create("test");
        CefRefPtr<CefListValue> browser_arg = browser_message->GetArgumentList();
        browser_arg->SetString(0, "hellow0");
        browser_arg->SetString(1, "hellow1");
        browser_arg->SetString(2, "hellow2");
        browser->GetMainFrame()->SendProcessMessage(PID_BROWSER, browser_message);

        return true;
    }

    return false;
}
void WebviewApp::OnContextCreated(CefRefPtr<CefBrowser> browser,
                                  CefRefPtr<CefFrame> frame,
                                  CefRefPtr<CefV8Context> context)
{
    // if (fuc_name_ == "")
    // {
    //     return;
    // }

    // CefRefPtr<CefV8Value> object = context->GetGlobal();

    // CefRefPtr<CefV8Handler> handler = new WebviewJSHandler("postMessage");

    // // Create the "myfunc" function.
    // CefRefPtr<CefV8Value> func = CefV8Value::CreateFunction("postMessage", handler);

    // // Add the "myfunc" function to the "window" object.
    // object->SetValue("postMessage", func, V8_PROPERTY_ATTRIBUTE_NONE);
}
void WebviewApp::OnBeforeCommandLineProcessing(const CefString &process_type,
                                               CefRefPtr<CefCommandLine> command_line)
{
    // disable creation of a GPUCache/ folder on disk
    command_line->AppendSwitch("disable-gpu-shader-disk-cache");

    command_line->AppendArgument("--enable-logging --v=1");
    command_line->AppendSwitch("in-process-gpu");
    // command_line->AppendSwitch("disable-accelerated-video-decode");

    // un-comment to show the built-in Chromium fps meter
    // command_line->AppendSwitch("show-fps-counter");

    // command_line->AppendSwitch("disable-gpu-vsync");

    // Most systems would not need to use this switch - but on older hardware,
    // Chromium may still choose to disable D3D11 for gpu workarounds.
    // Accelerated OSR will not at all with D3D11 disabled, so we force it on.
    //
    // See the discussion on this issue:
    // https://github.com/daktronics/cef-mixer/issues/10
    // //
    // command_line->AppendSwitchWithValue("use-angle", "d3d11");

    // // tell Chromium to autoplay <video> elements without
    // // requiring the muted attribute or user interaction
    // command_line->AppendSwitchWithValue("autoplay-policy", "no-user-gesture-required");

#if !defined(NDEBUG)
    // ~RenderProcessHostImpl() complains about DCHECK(is_self_deleted_)
    // when we run single process mode ... I haven't figured out how to resolve yet
    // command_line->AppendSwitch("single-process");
#endif
}
